unit fmChartTest;

interface

uses
  Windows, Messages, SysUtils, Variants, Classes, Graphics,
  Controls, Forms, Dialogs, TeeGDIPlus, TeEngine, Series, ExtCtrls,
  TeeProcs, Chart, StdCtrls, ComCtrls;

type
  TForm1 = class(TForm)
    btnCopy: TButton;
    imgChart: TImage;
    cbLabelsRight: TCheckBox;
    cbLabelsBottom: TCheckBox;
    btnRectangle: TButton;
    PageControl1: TPageControl;
    TabSheet1: TTabSheet;
    TabSheet2: TTabSheet;
    Panel1: TPanel;
    imgChartMem: TImage;
    TabSheet4: TTabSheet;
    procedure FormCreate(Sender: TObject);
    procedure FormDestroy(Sender: TObject);
    procedure btnCopyClick(Sender: TObject);
    procedure btnRectangleClick(Sender: TObject);
    procedure cbLabelsRightClick(Sender: TObject);
    procedure cbLabelsBottomClick(Sender: TObject);
  private
    { Private declarations }
    FChart: TChart;
    FChartMem: TChart;
    mySeries: TChartSeries;
  public
    { Public declarations }
  end;

var
  Form1: TForm1;

implementation

{$R *.dfm}

procedure TForm1.btnRectangleClick(Sender: TObject);
var
  myRect: TRect;
begin
  if Assigned(FChart) then
  begin
    FChart.Canvas.Pen.Color := clGreen;
    FChart.Canvas.Pen.Width := 2;
    FChart.Canvas.Brush.Style := bsClear;
    myRect := FChart.ChartRect;
    FChart.Canvas.Rectangle(myRect, 0);
  end;
end;

procedure TForm1.cbLabelsBottomClick(Sender: TObject);
begin
  FChart.Axes.Bottom.LabelsFormat.Visible := cbLabelsBottom.Checked;
end;

procedure TForm1.cbLabelsRightClick(Sender: TObject);
begin
  FChart.Axes.Right.LabelsFormat.Visible := cbLabelsRight.Checked;
end;

procedure TForm1.btnCopyClick(Sender: TObject);
var
  myRect: TRect;
begin
  if Assigned(imgChart) and Assigned(FChart) then
  begin
    myRect := imgChart.ClientRect;
    imgChart.Picture.Bitmap := FChart.TeeCreateBitmap(clWhite, myRect);
  end;

  myRect := imgChartMem.ClientRect;
  imgChartMem.Picture.Bitmap := FChartMem.TeeCreateBitmap(clWhite, myRect);
end;

procedure TForm1.FormCreate(Sender: TObject);

  function CreateChart(AParent: TWinControl=nil): TChart;
  var myRect: TRect;
  begin
    Result := TChart.Create(nil);

    with Result do
    begin
      if Assigned(AParent) then
      begin
        Parent:=AParent;
        Align:=alClient;
      end;

      View3D := false;
      Legend.Visible := false;
      Color := clRed;

      BackWall.Frame.Visible := false;
      BackWall.Gradient.Visible := false;
      BackWall.Color := clWhite;
      BackWall.Transparent := false;

      Axes.Right.Automatic := false;
      Axes.Right.Minimum := 0;
      Axes.Right.Maximum := 1000;
      Axes.Right.Inverted := true;
      Axes.Right.PositionPercent := 100;
      Axes.Right.LabelsOnAxis := false;
      Axes.Right.Visible := true;
      Axes.Right.Axis.Visible := false;
      Axes.Right.LabelsFormat.Visible := cbLabelsRight.Checked;
      Axes.Right.Grid.DrawAlways := true;
      Axes.Right.MinimumOffset := 50;

      Axes.Bottom.Automatic := false;
      Axes.Bottom.Minimum := 0;
      Axes.Bottom.Maximum := 100;
      Axes.Bottom.PositionPercent := 100;
      Axes.Bottom.LabelsOnAxis := false;
      Axes.Bottom.Visible := true;
      Axes.Bottom.Axis.Visible := false;
      Axes.Bottom.LabelsFormat.Visible := cbLabelsBottom.Checked;
      Axes.Bottom.Grid.DrawAlways := true;
      Axes.Bottom.MinimumOffset := 50;

      FreeAllSeries;
      AddSeries(CloneChartSeries(mySeries));

      Axes.Right.LabelsFormat.Visible := cbLabelsRight.Checked;
      Axes.Bottom.LabelsFormat.Visible := cbLabelsBottom.Checked;
      CustomChartRect := true;
      myRect := imgChart.ClientRect;

      TeeCreateBitmap(clWhite, myRect);

      InflateRect(myRect, Axes.Right.MaxLabelsWidth + Axes.Right.TickLength,
        Abs(Axes.Bottom.LabelsFont.Height) + Axes.Bottom.TickLength + 3);
      ChartRect := myRect;
    end;
  end;

begin
  mySeries := TLineSeries.Create(nil);
  mySeries.VertAxis := aRightAxis;
  mySeries.HorizAxis := aBottomAxis;
  mySeries.FillSampleValues(30);

  FChart:=CreateChart(TabSheet1);
  FChartMem:=CreateChart(nil);
end;

procedure TForm1.FormDestroy(Sender: TObject);
begin
  if Assigned(FChart) then
  begin
    FChart.FreeAllSeries;
    FChart.Free;
  end;

  FChartMem.FreeAllSeries;
  FChartMem.Free;
end;

end.
